@@ -27,6 +27,8 @@ SCRIPT_NAME=$(basename $0)
 
 #can make the upgrade script overridable (if a different target will be used)
 UPGRADE_SCRIPT=${UPGRADE_SCRIPT:-/root/tripleo_upgrade_node.sh}
+#allow override incase the ssh user is not 'heat-admin' - must be able to sudo
+UPGRADE_NODE_USER=${UPGRADE_NODE_USER:-"heat-admin"}
 UPGRADE_NODE=""
 QUERY_NODE=""
 SCRIPT=""
@@ -35,11 +37,13 @@ function show_options {
     echo "Usage: $SCRIPT_NAME"
     echo
     echo "Options:"
-    echo "    -h, --help                  -- print this help."
-    echo "    --upgrade <nova node>       -- nova node name or id to upgrade"
-    echo "    --script <absolute_path>    -- absolute path to the script you wish"
-    echo "                                   to use for the upgrade"
-    echo "    --query <nova node>         -- determine upgrade status on node"
+    echo "  -h|--help                    -- print this help."
+    echo "  -u|--upgrade <nova node>     -- nova node name or id to upgrade"
+    echo "  -s|--script <absolute_path>  -- absolute path to the script you wish"
+    echo "                                  to use for the upgrade"
+    echo "  -q|--query <nova node>       -- determine if the node is ACTIVE and"
+    echo "                                  has the upgrade script. Also, tail"
+    echo "                                  yum.log for any package update info"
     echo
     echo "Invoke the tripleo upgrade script on non controller nodes as part of"
     echo " the tripleo upgrade workflow."
@@ -47,7 +51,8 @@ function show_options {
     exit $1
 }
 
-TEMP=`getopt -o h -l help,upgrade:,query:,script: -n $SCRIPT_NAME -- "$@"`
+TEMP=`getopt -o h,u:,q:,s: -l help,upgrade:,query:,script: -n $SCRIPT_NAME -- "$@"`
+
 if [ $? != 0 ]; then
     echo "Terminating..." >&2
     exit 1
@@ -58,12 +63,12 @@ eval set -- "$TEMP"
 
 while true ; do
     case "$1" in
-        --help) show_options 0 >&2;;
-        --upgrade) UPGRADE_NODE="$2" ; shift 2 ;;
-        --script) SCRIPT="$2"; shift 2 ;;
-        --query) QUERY_NODE="$2" ; shift 2 ;;
-        --) shift ; break ;;
-        *) echo "Error: unsupported option $1." ; exit 1 ;;
+        -h | --help ) show_options 0 >&2;;
+        -u | --upgrade ) UPGRADE_NODE="$2" ; shift 2 ;;
+        -s | --script ) SCRIPT="$2"; shift 2 ;;
+        -q | --query ) QUERY_NODE="$2" ; shift 2 ;;
+        -- ) shift ; break ;;
+        * ) echo "Error: unsupported option $1." ; exit 1 ;;
     esac
 done
 
@@ -73,7 +78,7 @@ function log {
 
 function find_nova_node_by_name_or_id {
   name_or_id=$1
-  node_status=$(nova show $name_or_id | grep status | awk '{print $4}')
+  node_status=$(openstack server show $name_or_id -f value -c status)
   if ! [[ $node_status == "ACTIVE" ]]; then
     log "ERROR: node $name_or_id not found to be ACTIVE. Current status is $node_status"
     exit 1
@@ -85,7 +90,7 @@ function confirm_script_on_node {
   name_or_id=$1
   node_ip=$(nova show $name_or_id | grep "ctlplane network" | awk '{print $5}')
   log "checking for upgrade script $UPGRADE_SCRIPT on node $name_or_id ($node_ip)"
-  results=$(ssh heat-admin@$node_ip "sudo ls -l $UPGRADE_SCRIPT")
+  results=$(ssh $UPGRADE_NODE_USER@$node_ip "sudo ls -l $UPGRADE_SCRIPT")
   log "upgrade script $UPGRADE_SCRIPT found on node $name_or_id ($node_ip)"
 }
 
@@ -94,10 +99,10 @@ function deliver_script {
   node=$2
   node_ip=$(nova show $node | grep "ctlplane network" | awk '{print $5}')
   file_name=$(echo ${script##*/})
-  log "Sending upgrade script $script to $node_ip"
-  scp $script heat-admin@$node_ip:/home/heat-admin/$file_name
+  log "Sending upgrade script $script to $node_ip as $UPGRADE_NODE_USER"
+  scp $script $UPGRADE_NODE_USER@$node_ip:/home/$UPGRADE_NODE_USER/$file_name
   log "Copying upgrade script to right location and setting permissions"
-  ssh heat-admin@$node_ip "sudo cp /home/heat-admin/$file_name $UPGRADE_SCRIPT ; \
+  ssh $UPGRADE_NODE_USER@$node_ip "sudo cp /home/$UPGRADE_NODE_USER/$file_name $UPGRADE_SCRIPT ; \
                            sudo chmod 755 $UPGRADE_SCRIPT ; "
 }
 
@@ -109,12 +114,15 @@ if [ -n "$UPGRADE_NODE" ]; then
   confirm_script_on_node $UPGRADE_NODE
   node_ip=$(nova show $UPGRADE_NODE | grep "ctlplane network" | awk '{print $5}')
   log "Executing $UPGRADE_SCRIPT on $node_ip"
-  ssh heat-admin@$node_ip sudo $UPGRADE_SCRIPT
+  ssh $UPGRADE_NODE_USER@$node_ip sudo $UPGRADE_SCRIPT
 fi
 
 if [ -n "$QUERY_NODE" ]; then
-  # query for status, can remove this for simplicity
+  # check node exists, check for upgrade script
   find_nova_node_by_name_or_id $QUERY_NODE
+  confirm_script_on_node $QUERY_NODE
   node_ip=$(nova show $QUERY_NODE | grep "ctlplane network" | awk '{print $5}')
-  ssh heat-admin@$node_ip "sudo journalctl -n 1000 | grep tripleo-upgrade"
+  log "We can't remotely tell if the upgrade has run on $QUERY_NODE."
+  log "We can check for package updates... trying to tail yum.log on $QUERY_NODE:"
+  ssh $UPGRADE_NODE_USER@$node_ip "sudo tail /var/log/yum.log"
 fi
