@@ -64,7 +64,8 @@ class RegisterOrUpdateNodes(base.TripleOAction):
                 remove=self.remove,
                 glance_client=image_client,
                 kernel_name=self.kernel_name,
-                ramdisk_name=self.ramdisk_name)
+                ramdisk_name=self.ramdisk_name,
+                provide=False)
         except Exception as err:
             LOG.exception("Error registering nodes with ironic.")
             return mistral_workflow_utils.Result(
@@ -261,6 +262,8 @@ class ConfigureRootDeviceAction(base.TripleOAction):
 class UpdateNodeCapability(base.TripleOAction):
     """Update a node's capability
 
+    Set the node's capability to the specified value.
+
     :param node_uuid: The UUID of the node
     :param capability: The name of the capability to update
     :param value: The value to update token
