@@ -15,7 +15,6 @@
 
 
 #: The names of the root template in a standard tripleo-heat-template layout.
-TEMPLATE_NAME = 'overcloud-without-mergepy.yaml'
 OVERCLOUD_YAML_NAME = "overcloud.yaml"
 
 #: The name of the overcloud root template in jinja2 format.
@@ -24,6 +23,9 @@ OVERCLOUD_J2_NAME = "overcloud.j2.yaml"
 #: The name of custom roles data file used when rendering the jinja template.
 OVERCLOUD_J2_ROLES_NAME = "roles_data.yaml"
 
+#: The name of custom roles excl file used when rendering the jinja template.
+OVERCLOUD_J2_EXCLUDES = "j2_excludes.yaml"
+
 #: The name of the type for resource groups.
 RESOURCE_GROUP_TYPE = 'OS::Heat::ResourceGroup'
 
@@ -57,8 +59,12 @@ PASSWORD_PARAMETER_NAMES = (
     'AdminToken',
     'AodhPassword',
     'BarbicanPassword',
-    'CeilometerPassword',
     'CeilometerMeteringSecret',
+    'CeilometerPassword',
+    'CephAdminKey',
+    'CephClientKey',
+    'CephMonKey',
+    'CephRgwKey',
     'CinderPassword',
     'GlancePassword',
     'GnocchiPassword',
@@ -66,22 +72,20 @@ PASSWORD_PARAMETER_NAMES = (
     'HeatPassword',
     'HeatStackDomainAdminPassword',
     'IronicPassword',
+    'KeystoneCredential0',
+    'KeystoneCredential1',
+    'ManilaPassword',
     'MistralPassword',
     'MysqlClustercheckPassword',
+    'NeutronMetadataProxySharedSecret',
     'NeutronPassword',
     'NovaPassword',
     'RabbitPassword',
     'RedisPassword',
     'SaharaPassword',
+    'SnmpdReadonlyUserPassword',
     'SwiftHashSuffix',
     'SwiftPassword',
-    'SnmpdReadonlyUserPassword',
     'TrovePassword',
     'ZaqarPassword',
-    'ManilaPassword',
-    'NeutronMetadataProxySharedSecret',
-    'CephMonKey',
-    'CephAdminKey',
-    'CephClientKey',
-    'CephRgwKey',
 )
