@@ -26,29 +26,31 @@ class UpdateManagerTest(base.TestCase):
         super(UpdateManagerTest, self).setUp()
 
     @mock.patch('time.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    def test_update(self, mock_template_contents, mock_env_files, mock_time):
+    def test_update(self, mock_time):
         heatclient = mock.MagicMock()
         novaclient = mock.MagicMock()
         mock_time.return_value = 123.5
         heatclient.stacks.get.return_value = mock.MagicMock(
             stack_name='stack', id='stack_id')
-        mock_template_contents.return_value = ({}, 'template body')
-        mock_env_files.return_value = ({}, {})
+        stack_fields = {
+            'stack_id': 'stack_id',
+            'stack_name': 'mystack',
+            'template': 'template body',
+            'environment': {},
+            'files': {},
+        }
         update.PackageUpdateManager(
             heatclient=heatclient,
             novaclient=novaclient,
             stack_id='stack_id',
-            tht_dir='/tmp/'
+            stack_fields=stack_fields,
         ).update()
         params = {
             'existing': True,
+            'stack_name': 'mystack',
             'stack_id': 'stack_id',
             'template': 'template body',
             'files': {},
-            'parameters': {'UpdateIdentifier': 123},
             'environment': {
                 'resource_registry': {
                     'resources': {
@@ -58,9 +60,12 @@ class UpdateManagerTest(base.TestCase):
                             }
                         }
                     }
-                }
+                },
+                'parameter_defaults': {
+                    'UpdateIdentifier': 123,
+                    'StackAction': 'UPDATE'
+                },
             },
             'timeout_mins': 240,
         }
         heatclient.stacks.update.assert_called_once_with(**params)
-        mock_env_files.assert_called_once_with(env_paths=[])
